@@ -1,5 +1,6 @@
 /*
 # Copyright 1999-2003 Alla Bezroutchko <alla@inetcat.org>
+# Copyright 2021      Mayco Souza Berghetti <mayco.s.berghetti@gmail.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -19,8 +20,15 @@
 #if !defined ERRORS_H
 #define ERRORS_H
 
-#define err_die(error, quiet) if(!quiet) {perror(error); exit(1);};
+#define err_die( error, quiet ) \
+  if ( !quiet )                 \
+    {                           \
+      perror ( error );         \
+      exit ( 1 );               \
+    };
 
-#define err_print(error, quiet) if(!quiet) perror(error);
+#define err_print( error, quiet ) \
+  if ( !quiet )                   \
+    perror ( error );
 
 #endif /* ERRORS_H */
