@@ -1,5 +1,6 @@
 /*
 # Copyright 1999-2003 Alla Bezroutchko <alla@inetcat.org>
+# Copyright 2021      Mayco Souza Berghetti <mayco.s.berghetti@gmail.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,22 +19,32 @@
 
 #define ERROR 12345
 
-struct list_item {
-	struct list_item* next;
-	struct list_item* prev;
-	unsigned long content;
+struct list_item
+{
+  struct list_item *next;
+  struct list_item *prev;
+  unsigned long content;
 };
 
-struct list {
-	struct list_item* head;
+struct list
+{
+  struct list_item *head;
 };
 
-struct list* new_list(); 
+struct list *
+new_list ();
 
-struct list_item* new_list_item(unsigned long content);
+struct list_item *
+new_list_item ( unsigned long content );
 
-void delete_list(struct list* list);
-	
-int compare(struct list_item* item1, struct list_item* item2);
+void
+delete_list ( struct list *list );
 
-int insert(struct list* lst, unsigned long content);
+int
+compare ( struct list_item *item1, struct list_item *item2 );
+
+int
+insert ( struct list *lst, unsigned long content );
+
+int
+in_list ( struct list *lst, unsigned long content );
